"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable global-require */
/* eslint-disable max-len */
const path_1 = require("path");
const lodash_set_1 = __importDefault(require("lodash.set"));
const camelcase_1 = __importDefault(require("camelcase"));
const glob = require("glob");
const funcNameFromRelPath = (relpath) => {
    const relPath = relpath;
    const relPathArray = relPath.split('/');
    const fileName = relPathArray.pop();
    const relDirPathFunctionNameChunk = relPathArray.map((pathFragment) => camelcase_1.default(pathFragment)).join('/');
    const fileNameFunctionNameChunk = camelcase_1.default(fileName.split('.')[0]);
    return [relDirPathFunctionNameChunk, fileNameFunctionNameChunk].join('/').replace(/\//g, '-');
};
/**
 * This function will search the given directory using provided glob matching pattern.
 * All matching files will then be checked for a default export. The filename and path is
 * used to determine the function name on deployment.
 *
 * You can set the glob pattern to only pick up files that end in *.cf.js or *.function.js
 * Be sure to use `js` as your file extension when matching if you are using Typescript
 *
 * @param glob `string` the glob pattern to search `dir` for function files
 * @param dir `string` the directory to search in.
 * @returns `exports` object - just do exports = exportCloudFunctions...
 *
 * @example import exportCloudFunctions from 'better-firebase-functions'
 * exports = exportCloudFunctions(__dirname, __filename, exports, './', GLOB_PATTERN);
 */
exports.default = (__dirname, __filename, exports, dir, globPattern) => {
    const funcDir = dir || './';
    const pat = globPattern || './**/*.js';
    const files = glob.sync(pat, { cwd: path_1.resolve(__dirname, funcDir) });
    // eslint-disable-next-line no-restricted-syntax
    for (const file of files) {
        const absPath = path_1.resolve(__dirname, funcDir, file);
        // eslint-disable-next-line no-continue
        if (absPath.slice(0, -2) === __filename.slice(0, -2))
            continue; // Prevent exporting this file if present
        const absFuncDir = path_1.resolve(__dirname, funcDir);
        const relPath = absPath.substr(absFuncDir.length + 1); /* ? */
        const funcName = funcNameFromRelPath(relPath); /* ? */
        const propPath = funcName.replace(/-/g, '.'); /* ? */
        if (!process.env.FUNCTION_NAME || process.env.FUNCTION_NAME === funcName) {
            // eslint-disable-next-line import/no-dynamic-require
            const module = require(path_1.resolve(__dirname, funcDir, relPath));
            // eslint-disable-next-line no-continue
            if (!module.default)
                continue;
            lodash_set_1.default(exports, propPath, module.default);
        }
    }
    return exports;
};
//# sourceMappingURL=index.js.map